@@ -20,22 +20,35 @@ def generate_object_id():
 def remove_exponent(value: Decimal):
     return value.to_integral() if value == value.to_integral() else value.normalize()
 
+def is_number(value: str):
+    try:
+        return True, float(value)
+    except ValueError:
+        pass
+    return False, value
+
 def format_value(value: str, scale: str, decimal: int = 2) -> str:
     value = str(value)
-    scale = str(scale)
+    scale_num, scale = is_number(str(scale))
     if len(value) > 0:
         try:
             if value.lower() == 'true':
                 value = '1'
             elif value.lower() == 'false':
                 value = '0'
-            value = float(value)
-            if scale != '1':
-                value = value * float(scale)
-            format = f"%.{decimal}f"
 
-            value = format % value  # 格式化小数点
-            value = remove_exponent(Decimal(value))
+            value_num, value = is_number(str(value))
+            if value_num is True:
+                if scale_num:
+                    if scale != float('1'):
+                        value = value * scale
+                else:
+                    if len(scale) > 0:
+                        v = value
+                        value = eval(scale)
+                format = f"%.{decimal}f"
+                value = format % value  # 格式化小数点
+                value = remove_exponent(Decimal(value))
         except Exception as e:
             pass
     return str(value)
